[tor-commits] [pluggable-transports/snowflake] 07/13: Use uTLS aware broker channel constructor

gitolite role git at cupani.torproject.org
Wed Mar 16 09:14:15 UTC 2022


This is an automated email from the git hooks/post-receive script.

shelikhoo pushed a commit to branch main
in repository pluggable-transports/snowflake.

commit 1573502e93b7149e8a4784e62bb1adc979312940
Author: Shelikhoo <xiaokangwang at outlook.com>
AuthorDate: Fri Feb 11 10:03:45 2022 +0000

    Use uTLS aware broker channel constructor
---
 client/lib/rendezvous.go | 6 +++---
 client/lib/snowflake.go  | 5 +++--
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/client/lib/snowflake.go b/client/lib/snowflake.go
index 510567e..e309b44 100644
--- a/client/lib/snowflake.go
+++ b/client/lib/snowflake.go
@@ -131,8 +131,9 @@ func NewSnowflakeClient(config ClientConfig) (*Transport, error) {
 	}
 
 	// Rendezvous with broker using the given parameters.
-	broker, err := NewBrokerChannel(
-		config.BrokerURL, config.AmpCacheURL, config.FrontDomain, config.KeepLocalAddresses)
+	broker, err := NewBrokerChannelWithUTlsSettings(
+		config.BrokerURL, config.AmpCacheURL, config.FrontDomain,
+		config.KeepLocalAddresses, config.UTlsClientID, config.UTlsRemoveSNI)
 	if err != nil {
 		return nil, err
 	}

diff --git a/client/lib/rendezvous.go b/client/lib/rendezvous.go
index 7c27dfc..ee07600 100644
--- a/client/lib/rendezvous.go
+++ b/client/lib/rendezvous.go
@@ -56,13 +56,13 @@ func createBrokerTransport() http.RoundTripper {
 }
 
 func NewBrokerChannel(broker, ampCache, front string, keepLocalAddresses bool) (*BrokerChannel, error) {
-	return NewBrokerChannelWithUTlsClientID(broker, ampCache, front, keepLocalAddresses, "", false)
+	return NewBrokerChannelWithUTlsSettings(broker, ampCache, front, keepLocalAddresses, "", false)
 }
 
 // NewBrokerChannelWithUTlsClientID construct a new BrokerChannel, where:
 // |broker| is the full URL of the facilitating program which assigns proxies
 // to clients, and |front| is the option fronting domain.
-func NewBrokerChannelWithUTlsClientID(broker, ampCache, front string, keepLocalAddresses bool, utlsClientID string, removeSNI bool) (*BrokerChannel, error) {
+func NewBrokerChannelWithUTlsSettings(broker, ampCache, front string, keepLocalAddresses bool, utlsClientID string, removeSNI bool) (*BrokerChannel, error) {
 	log.Println("Rendezvous using Broker at:", broker)
 	if ampCache != "" {
 		log.Println("Through AMP cache at:", ampCache)
@@ -56,13 +56,13 @@ func createBrokerTransport() http.RoundTripper {
 }
 
-// NewBrokerChannelWithUTlsClientID construct a new BrokerChannel, where:
+// NewBrokerChannelWithUTlsSettings construct a new BrokerChannel, where:
 // |broker| is the full URL of the facilitating program which assigns proxies
 // to clients, and |front| is the option fronting domain.
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the tor-commits mailing list